#define DEFAULT_TIMEOUT 5.0
#define DEFAULT_MARKUP_BROWSER 	"[%name%: &[%artist% - ]%title%]|%name%|[%artist% - ]%title%|%shortfile%|"
#define DEFAULT_PLAYLIST_MARKUP "[%name%: &[%artist% - ]%title%]|%name%|[%artist% - ]%title%|%shortfile%|"
#define DEFAULT_PLAYER_MARKUP 	"[%name%: &[%artist% - ]%title%]|%name%|[%artist% - ]%title%|%shortfile%|"
#define DEFAULT_HIDE_ON_STARTUP 0
#define DEFAULT_TRAY_ICON_ENABLE 1
#define DEFAULT_AUTOCONNECT 0
#define DEFAULT_TRAY_MARKUP "[<span size=\"small\">%name%</span>\n][<span size=\"large\" weight=\"bold\">%title%</span>\n][%artist%][\n<span size=\"small\">%album% [(track %track%)]</span>]|%shortfile%|"


#define DEFAULT_PLAYLIST_PLAYER_MARKUP "<span size=\"large\" weight=\"bold\">[%title%|%shortfile%]</span>\n[<span size=\"small\">%name%</span>]<span size=\"small\">[ By <b>%artist%</b>[ From <b>%album%</b>]]</span>"

/*"[<span size=\"small\">%name%</span>\n][<span size=\"large\" weight=\"bold\">%title%</span>\n]<span size=\"small\">[<span color='dark grey'>by</span> %artist%][ <span color='dark grey'>From</span> %album%]</span>|%shortfile%|"*/

